@@ -109,7 +109,9 @@ pub(crate) async fn list(
             .map(|a| PythonDownloadRequest::iter_downloads(a, python_downloads_json_url.as_deref()))
             .transpose()?
             .into_iter()
-            .flatten();
+            .flatten()
+            // TODO(zanieb): Add a way to show debug downloads, we just hide them for now
+            .filter(|download| download.key().variant() != &uv_python::PythonVariant::Debug);
 
         for download in downloads {
             output.insert((
